# Dash Charlotte

A package of themes, tools and components for Plotly-Dash web dashboards.

**TL;DR:** This is a personal project, so I'd suggest not taking this too seriously.

## Dash Charlotte is...

- ... a package to speed up the creation of dashboards with standardized components;
- ... a bunch of components that I often use on my personal projects.

## Dash Charlotte is NOT...

- ... ready for production use. The structure, arguments or behavior of the components are not set in stone and change regularly depending on the ease of use observed in testing;
- ... created in React (yet). Because of this, some components might not follow Dash rules and standards.

## Submodules

Click on the following link to check each submodule documentation.

- [**Components**](https://github.com/GusFurtado/dash-charlotte/tree/main/dash_charlotte/components): A set of standard Dash components for a fast and modular dashboard building.

- [**Themes**](https://github.com/GusFurtado/dash-charlotte/tree/main/dash_charlotte/themes): Tools for easy and consistent styling. Colors, fonts, icon packages and CSS stuff.

- [**Layouts**](https://github.com/GusFurtado/dash-charlotte/tree/main/dash_charlotte/layouts): Some pre-built page layouts.

## Instatlation

- `pip install dash-charlotte`

## License

- [**MIT**]([LICENSE])

## Getting Started

Check the [example app](https://github.com/GusFurtado/dash-charlotte-live-demo) or the [live demo](https://dash-charlotte.herokuapp.com/).
